==> arq-2.8.4-sources.jar: com/hp/hpl/jena/sparql/core/DatasetGraphMaker.java <==
/*
 * (c) Copyright 2010 Talis Systems Ltd.
 * All rights reserved.
 * [See end of file]
 */

package com.hp.hpl.jena.sparql.core;

import com.hp.hpl.jena.graph.Graph ;
import com.hp.hpl.jena.graph.Node ;

/** Implementation of a DatasetGraph as an open set of graphs where all graphs "exist".
 *  New graphs are created (via the policy of a GraphMaker) when a getGraph call is 
 *  made to a graph that has not been allocated.
 */
public class DatasetGraphMaker extends DatasetGraphMap
{
    public interface GraphMaker { public Graph create() ; }

    private static GraphMaker graphMakerNull = new GraphMaker() {
        public Graph create()
        {
            return null ;
        } } ;

    private GraphMaker graphMaker ;

    public DatasetGraphMaker(GraphMaker graphMaker)
    {
        super(graphMaker.create()) ;
        this.graphMaker = graphMaker ;
    }

    public DatasetGraphMaker(Graph graph)
    {
        super(graph) ;
        this.graphMaker = graphMakerNull ;
    }
    
    @Override
    public boolean containsGraph(Node graphNode)
    {
        return true ;
    }

    @Override
    public Graph getGraph(Node graphNode)
    {
        Graph g = super.getGraph(graphNode) ;
        if ( g == null )
        {
            g = graphMaker.create() ;
            if ( g != null )
                super.addGraph(graphNode, g) ;
        }
        return g ;
    }
}

/*
 * (c) Copyright 2010 Talis Systems Ltd.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

==> arq-2.8.7-sources.jar: com/hp/hpl/jena/sparql/core/DatasetGraphMaker.java <==
/*
 * (c) Copyright 2010 Talis Systems Ltd.
 * All rights reserved.
 * [See end of file]
 */

package com.hp.hpl.jena.sparql.core;

import com.hp.hpl.jena.graph.Graph ;
import com.hp.hpl.jena.graph.Node ;

/** Implementation of a DatasetGraph as an open set of graphs where all graphs "exist".
 *  New graphs are created (via the policy of a GraphMaker) when a getGraph call is 
 *  made to a graph that has not been allocated.
 */
public class DatasetGraphMaker extends DatasetGraphMap
{
    public interface GraphMaker { public Graph create() ; }

    private static GraphMaker graphMakerNull = new GraphMaker() {
        public Graph create()
        {
            return null ;
        } } ;

    private GraphMaker graphMaker ;

    public DatasetGraphMaker(GraphMaker graphMaker)
    {
        super(graphMaker.create()) ;
        this.graphMaker = graphMaker ;
    }

    public DatasetGraphMaker(Graph graph)
    {
        super(graph) ;
        this.graphMaker = graphMakerNull ;
    }
    
    @Override
    public boolean containsGraph(Node graphNode)
    {
        //return true ;
        return super.containsGraph(graphNode) ;
    }

    @Override
//    public Graph getGraph(Node graphNode)
//    {
//        Graph g = super.getGraph(graphNode) ;
//        if ( g == null )
//        {
//            g = graphMaker.create() ;
//            if ( g != null )
//                super.addGraph(graphNode, g) ;
//        }
//        return g ;
//    }
    
    protected Graph getGraphCreate()
    {
        return graphMaker.create() ;
    }
}

/*
 * (c) Copyright 2010 Talis Systems Ltd.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
